@@ -1,5 +1,5 @@
 package Mira::Control::Parser::Markup;
-$Mira::Control::Parser::Markup::VERSION = '00.07.41';
+$Mira::Control::Parser::Markup::VERSION = '00.07.42';
 
 use strict;
 use warnings;
@@ -60,7 +60,7 @@ sub markup {
         $lessbody =~ s:^\s*$::mg;
         $lessbody =~ s/(.{0,600}).*/$1/s;
         $body->{less} = "<p>" . $lessbody . "</p>";
-        $body->{more} = "<a name=\"more\"></a><br>" . $fbody;
+        $body->{more} = "<a name=\"more\"></a>\n" . $fbody;
     }
 
     return $body;
